; File: SimCo-simple.nlogo
;
; Simco training tool v0.2
;
; Shares the code base with SimCo, but provides an easier to use GUI.
;
; 2017
;
; Fabian Adelt, Johannes Weyer, Robin D. Fink, Andreas Ihrig (TU Dortmund University)
;
; Licence:
;
;    This program is free software: you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation, either version 3 of the License, or
;    (at your option) any later version.
;    This program is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;    You should have received a copy of the GNU General Public License
;    along with this program.  If not, see <http://www.gnu.org/licenses/>.
;
; Extensions:
;   table - helpers for tables
;   array - helpers for arrays
;   string - string handling
;   goo - change gui-elements
;   pathdir - directory handling
;   file - file handling
;   stats - handling of simulation data, including some basic statistic methods
;   profiler - measuring time each functions needs (calling sub-functions included and excluded) as well as number of calls
;
; Includes:
;   setup.nls - contains all setup routines (<libs/setup.nls>)
;   variables.nls - contains all breed- and global-variabelles (<libs/variables.nls>)
;   helpers.nls - contains some helper functions (<libs/helpers.nls>)
;   helpers-simco.nls - contains some helper functions which are solely usable within simco (<libs/helpers-simco.nls>)
;   helpers-visualization.nls - contains code for visual representation of the macro-layer (<libs/helpers-visualization.nls>)
;   helpers-visualization-simco.nls - contains code for visual representation of the macro-layer which are solely usable within SimCo (<libs/helpers-visualization-simco.nls>)
;   hubnet.nls - contains code for hubnet features (<libs/hubnet.nls>)
;   automated-control.nls - contains routines for the automated control (<libs/automated-control.nls>)
;   helpers-SEU.nls - contains routines and helpers for agents' decision-taking, based on subjective expected utility (SEU) (<libs/helpers-SEU.nls>)
;   helpers-input.nls - contains helper functions for reading input files (<libs/helpers-input.nls>)
;   helpers-output.nls - contains helper functions for writing output files, generating the respective file-names etc. (<libs/helpers-output.nls>)
;   helpers-file-handling.nls - contains  functions to handle files and folders (<libs/helpers-file-handling.nls>)
;   helpers-lists.nls - contains functions for basic list operations (<libs/helpers-lists.nls>)
;   interactions.nls - contains functions handling all interactions between <agents>, <technologies> and infrastructure elements (<nodes> and <edges>) (<libs/interactions.nls>)
;
;
extensions [
             table
             array
             string
             goo
             pathdir
             file
             stats
             profiler
           ]
__includes [
             "libs/setup.nls"
             "libs/variables.nls"
             "libs/helpers.nls"
             "libs/helpers-simco.nls"
             "libs/helpers-visualization.nls"
             "libs/helpers-visualization-simco.nls"
             "libs/hubnet.nls"
             "libs/automated-control.nls"
             "libs/helpers-SEU.nls"
             "libs/helpers-input.nls"
             "libs/helpers-output.nls"
             "libs/helpers-file-handling.nls"
             "libs/helpers-lists.nls"
             "libs/interactions.nls"
]
; Breed: global
;
; Some global variables which are present in full SimCo's GUI and need to be substituted here.
;
; Variables: global variables
;   out-level - string, indicating which level of information shall be used by "out" function
;   debug-level - int, indicating which level of information shall be used by "debug" function
;   out? - bool, shall "out" output be printed?
;   debugging? - bool, shall "debug" output be printed?
;   hubnet? - bool, shall hubnet part of Simco be started? Used for alternative views, experimental.
;   use-snf - bool, shall the standard scenario format "snf" be used?
;   out-who - int, indicating which agent shall be used for inspection in full SimCo
;   followme? - bool, shall an agent by marked in GUI to follow it's movement?
;   inspect? - bool, shall
;   save-history? - bool,
;   purchase? - bool,
;   l-e-z-f - int,
;   l-e-z-r - int,
;   visualize-node -
;
globals [out-level debug-level out? debugging? hubnet? use-snf out-who followme? inspect? save-history? purchase? l-e-z-f l-e-z-r visualize-node]





; Function: go
; Main function to run the simulation.
;
to go
  ;debug 4 "go"
  ;test if user loaded setup files and ticks are reseted
;  carefully [
;
  if hubnet? [receive-hubnet-messages]
  check-payoff-reset
  check-death
  if (count agents = 0) [stop]
  if (purchase?) [purchase-technology]
  agents-run
  degrade-all
  if (not automated-run?)[
    update-edges-visualization
    update-nodes-visualization
    update-agents-visualization
  ]
  update-globals

  if(save-history?)[update-history]
  if automated-control? [automated-control]

  tick
 ; if automated-run? [print ticks]
 ;  ]
 ; [
 ; user-message (word "An error occured:\n" error-message "\n\nPlease contact the developer team if this happens again.")
 ;   stop
 ;]
end

; Function: degrade-all
; Decreases all pay-offs by the <global->global-agents-degradation> vector for <agents>, <nodes> and <edges>.
; Furthermore, lifetime-values  of <nodes>, <edges> and <technologies> are reduced by 1.
;
to degrade-all
  ;debug 4 "degrade-all"

  if ((reduce + global-agents-degradation) > 0) [
    ask agents [
      let i 0
      let short []
      let long []
      let total []
      repeat number-dimensions [
        set short lput (item i agent-pay-offs-short-time - item i global-agents-degradation) short
        set long lput (item i agent-pay-offs-long-time - item i global-agents-degradation) long
        set total lput (item i agent-pay-offs - item i global-agents-degradation) total
        set i i + 1
      ]
      set agent-pay-offs-short-time short
      set agent-pay-offs-long-time long
      set agent-pay-offs total
    ]
  ]
  ; increase age irrespecitve of gobal-agents-degradation
  ask agents [
    set agent-age agent-age + 1
  ]

  if ((reduce + global-nodes-degradation) > 0 )[
    ask nodes [
      let i 0
      let short []
      let long []
      let total []
      repeat number-dimensions [
        set short lput (item i node-pay-offs-short-time - item i global-nodes-degradation) short
        set long lput (item i node-pay-offs-long-time - item i global-nodes-degradation) long
        set total lput (item i node-pay-offs - item i global-nodes-degradation) total
        set i i + 1
      ]
      set node-pay-offs-short-time short
      set node-pay-offs-long-time long
      set node-pay-offs total
      set node-lifetime node-lifetime - 1
    ]
  ]
  if ((reduce + global-edges-degradation) > 0 )[
    ask edges [
      let i 0
      let short []
      let long []
      let total []
      repeat number-dimensions [
        set short lput (item i edge-pay-offs-short-time - item i global-edges-degradation) short
        set long lput (item i edge-pay-offs-long-time - item i global-edges-degradation) long
        set total lput (item i edge-pay-offs - item i global-edges-degradation) total
        set i i + 1
      ]
      set edge-pay-offs-short-time short
      set edge-pay-offs-long-time long
      set edge-pay-offs total
      set edge-lifetime edge-lifetime - 1
    ]
  ]

  ask technologies [
    set technology-lifetime technology-lifetime - 1
  ]
end


; Function: agents-run
; Main function for all <agent> actions: Entering and leaving <nodes> and <edges> and taking decisions about the next <node> an agent wants to reach.
;;
to agents-run
  ;debug 4 "agents-run"
  ask agents [
    ;check if agent is on node, first.
    ;Otherwise, agents leaving an edge and entering a node will decide about the next action to take in the same moment and will not stay at the node for even one tick. This would bypass any capacity-limit on nodes!
    if ([breed] of agent-location = nodes) [
      ; check wether any the agent's technologies has reached its end of lifetime.
      check-technologies-death agent-technologies-available

      ;Choose an action to take. This includes a destination <node>, an <edge> and a <technology>.
      let my-action choose-action
      ;check, that choose-action returned a valid result, i.e. an action the agent may take.
      if-else (my-action != []) [
        ;;handle interaction with node to leave (location)
        interact self agent-technology-in-use agent-location

        ;out 3 (word "decision taken: " my-action) who
        set agent-destination item 0 my-action
        let edge-to-use item 1 my-action
        set agent-technology-in-use item 2 my-action
        if agent-technology-in-use = nobody [user-message "alert"]
        ;out 3 (word "dest: " agent-destination " of " agent-id) who
        ;;handle interaction with edge to jump on (sets agent-location as well)
        interact self agent-technology-in-use edge-to-use
        set agent-edge-delay calculate-edge-delay edge-to-use agent-technology-in-use
      ][
        ; no new destination found - stay on the node you are actually on. (possible deadlock!)
        set agent-destination agent-location
        if payoff-node-per-tick?[
        ;todo future version: calculate payoffs in case of node-pay-off-per-tick. What about technology in use? Actually, the actor *has* to use some technology or we do need a "no-tech-tech-multiplication-vector".
        ]
      ]
    ]

    ; If the agent is located on an edge and waited long enough (agent-edge-delay <== 0), the agent will enter the node connected to that edge.
    if ([breed] of agent-location = edges) [
      ifelse (agent-edge-delay <= 0) [
        ;handle interaction with edge to leave (agent-location) and node to jump on (agent-destination)
        interact self agent-technology-in-use agent-location
        interact self agent-technology-in-use agent-destination
      ][
        ;the agent has to wait on the edge, because agent-edge-delay is > 0
        set agent-edge-delay agent-edge-delay - 1
        if payoff-edge-per-tick?[
         ;todo future version: calculate payoffs in case of edge-pay-off-per-tick
        ]
      ]
    ]
  ]
end




;##############################################################################
; Updates
;##############################################################################

; Function: update-history
; Updates history for all elements of the simulation. Should be used once per tick.
; Called from go-function, if <save-history?> is true.
;
to update-history
  ;debug 4 "update-history"
  let stats-information ""
  ; externals and global measures
  let history-information []
  ;measure technology usage
  let tech-usage []

  if (wg-sr? or wg-s?) [
    foreach sort-on [technology-type-name] technology-types [
      set tech-usage lput (count agents with [technology-type-in-use? ?]) tech-usage
    ]
    ;measure edges with banned technologies
    let techs-banned-edges []
    let i 0
    ;count edges with zero to (number of technology-types) technology-types banned.
    repeat count technology-types + 1 [
      set techs-banned-edges lput (count edges with [number-of-technologies-banned self = i]) techs-banned-edges
      set i i + 1
    ]
    let banned-techs-edges []
    ;for each technoloy type: count edges on which that technology-type is banned
    foreach sort-on [who] technology-types [
      set banned-techs-edges lput (count edges with [technology-allowed-on? self [technology-type-name] of ?]) banned-techs-edges
    ]
    ;memorize payoffs, information retrieved above and values of automated-control variables
    set stats-information (sentence external-pay-offs-short-time external-pay-offs-long-time tech-usage techs-banned-edges banned-techs-edges percentage-strong-automated-control percentage-soft-automated-control)
    stats:add stats stats-information
  ]

  ; nodes
  if (wn-s? or wn-sr? or wn-h?) [
    ask nodes [
      set stats-information (sentence node-pay-offs-short-time node-pay-offs-long-time node-degree-short-time node-degree-long-time node-costs-benefits-agents-control-factor-per-technology)
      set history-information (list sort-on [agent-id] node-agents )
      stats:add node-stats stats-information
      table:put node-history ticks history-information
    ]
  ]

  ; edges
  if (we-s? or we-sr? or we-h?) [
    ask edges [
      set stats-information (sentence edge-pay-offs-short-time edge-pay-offs-long-time edge-degree-short-time edge-degree-long-time edge-costs-benefits-agents-control-factor-per-technology get-edge-technology-banned)
      set history-information (list sort-on [agent-id] edge-agents)
      stats:add edge-stats stats-information
      table:put edge-history ticks history-information
    ]
  ]

  ; technology-types
  if (wt-sr? or wt-s?) [
    ask technology-types [
      set stats-information (sentence technology-type-control-factor technology-type-control-duration-factor)
      stats:add technology-type-stats stats-information
    ]
  ]

  ; agents
  if (wa-h? or wa-sr? or wa-s?) [
    ask agents [
      let my-count-direct-neighbors 0
      let my-count-neighbors 0
      ifelse ([breed] of agent-location = nodes)[
        ;count other agents on a) the node I am actually on and b) the following node and the edge connecting both.
        set my-count-direct-neighbors count [node-agents] of agent-location
        set my-count-neighbors my-count-direct-neighbors
        let my-neighbors compute-neighbours agent-location
        foreach my-neighbors [
          set my-count-neighbors my-count-neighbors + count [node-agents] of item 0 ?
          set my-count-neighbors my-count-neighbors + count [edge-agents] of edge [who] of agent-location [who] of item 0 ?
        ]
      ][
      ; count agents on edge I am actually on, and additionally agents on the following node
      set my-count-direct-neighbors count [edge-agents] of agent-location
      set my-count-neighbors my-count-direct-neighbors +  count [node-agents] of get-to-node agent-location

      ]
      set stats-information (sentence agent-pay-offs-short-time agent-pay-offs-long-time agent-degree-short-time agent-degree-long-time my-count-direct-neighbors my-count-neighbors )
      set history-information (list agent-stuck?  [technology-name] of agent-technology-in-use agent-location )
      stats:add agent-stats stats-information
      table:put agent-history ticks history-information
    ]
  ]

end





;##############################################################################
; Hubnet
;##############################################################################

; Function: startup
; Starts the hubnet functions
;
to startup
  ;debug 4 "startup"
  set simco-simple? false
  set hubnet? false
  if hubnet? [hubnet-reset]
end
@#$#@#$#@
GRAPHICS-WINDOW
330
20
958
633
17
16
17.66
1
10
1
1
1
0
0
0
1
-17
17
-16
16
1
1
1
ticks
30.0

BUTTON
15
20
145
53
Setup
clear-all\nset automated-run? false\nset simco-simple? true\nsetup\nupdate-globals
NIL
1
T
OBSERVER
NIL
S
NIL
NIL
1

BUTTON
15
60
145
93
Go
if (\n  count agents <= 0 OR\n  count edges <= 0 OR\n  count nodes <= 0 OR\n  count technologies <= 0) \n [user-message \"Number of agents, technologies, nodes or edges went down to zero! Simulation will halt now.\"stop]\ngo\n
T
1
T
OBSERVER
NIL
G
NIL
NIL
0

BUTTON
155
60
285
93
Go once
go
NIL
1
T
OBSERVER
NIL
O
NIL
NIL
0

CHOOSER
150
195
285
240
Visualization-dimension
Visualization-dimension
"Capacity" "Money" "Type" "Emission" "Comfort"
0

BUTTON
155
20
285
53
Reload model
__reload
NIL
1
T
OBSERVER
NIL
R
NIL
NIL
1

SWITCH
10
245
142
278
Show-degree?
Show-degree?
1
1
-1000

CHOOSER
10
195
140
240
Time-intervall
Time-intervall
"short" "long"
0

SLIDER
10
380
305
413
percentage-soft-automated-control
percentage-soft-automated-control
0
1
0.6
0.01
1
%
HORIZONTAL

SLIDER
10
415
305
448
percentage-strong-automated-control
percentage-strong-automated-control
0
1
0.8
0.01
1
%
HORIZONTAL

CHOOSER
10
465
185
510
Technology-to-influence
Technology-to-influence
"bike" "car" "ev" "pt"
1

CHOOSER
10
515
185
560
Technology-dimension-to-influence
Technology-dimension-to-influence
"Capacity" "Money" "Type" "Emission" "Comfort"
1

INPUTBOX
10
565
185
625
Technology-value
1
1
0
Number

BUTTON
195
480
307
513
Increase value
increase-technology-value technology-to-influence technology-dimension-to-influence
NIL
1
T
OBSERVER
NIL
+
NIL
NIL
0

BUTTON
195
520
305
553
Decrease value
decrease-technology-value technology-to-influence technology-dimension-to-influence
NIL
1
T
OBSERVER
NIL
-
NIL
NIL
0

MONITOR
470
690
600
735
Number of  agents  stuck
count agents with [agent-stuck?]
2
1
11

PLOT
970
20
1275
190
Technologies used (in %)
ticks
%
0.0
10.0
0.0
100.0
true
true
"foreach sort-on [technology-type-name] technology-types [\n  create-temporary-plot-pen [technology-type-name] of ?\n  set-plot-pen-color 8 * [who] of ?\n  ]" "if (count technologies > 0) [\nforeach sort-on [technology-type-name] technology-types [\n  set-current-plot-pen [technology-type-name] of ?\n  plot (count agents with [[technology-name] of agent-technology-in-use = [technology-type-name] of ?]) / (count agents) * 100\n  ]\n  ]"
PENS

PLOT
970
485
1275
635
Edges with banned technologies (number)
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"let i 1\nforeach sort-on [technology-type-name] technology-types [\n  create-temporary-plot-pen (word i)\n  set-plot-pen-color 23 * [who] of ?\n  set i i + 1\n  ]" "let i 1\nrepeat count technology-types [\n  set-current-plot-pen (word i)\n  plot count edges with [number-of-technologies-banned self = i]\n  set i i + 1\n  ]"
PENS

SWITCH
10
295
155
328
automated-control?
automated-control?
1
1
-1000

TEXTBOX
125
445
275
463
NIL
11
0.0
1

TEXTBOX
-5
170
385
196
========================================
11
0.0
1

TEXTBOX
0
280
400
306
========================================
11
0.0
1

TEXTBOX
0
450
305
476
====================================
11
0.0
1

TEXTBOX
0
625
385
651
========================================
11
0.0
1

BUTTON
320
675
437
708
Grow population
repeat quantity-to-grow-population [\nask one-of agents [hatch-agent]\n]\n\n
NIL
1
T
OBSERVER
NIL
H
NIL
NIL
0

SLIDER
320
640
500
673
Quantity-to-grow-population
Quantity-to-grow-population
0
100
100
1
1
NIL
HORIZONTAL

PLOT
830
640
1070
790
Mean degree edges (short)
NIL
NIL
0.0
10.0
0.0
1.0
true
true
"foreach names-of-dimensions [\n  create-temporary-plot-pen ?\n  set-plot-pen-color 22 * get-dimension ?\n]" "if (count edges > 0) [\nforeach names-of-dimensions [\nset-current-plot-pen ?\nplot mean [item get-dimension ? edge-degree-short-time] of edges\n]\n]"
PENS

PLOT
1075
640
1275
790
Max degree edges (short)
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"foreach names-of-dimensions [\n  create-temporary-plot-pen ?\n  set-plot-pen-color 22 * get-dimension ?\n]" "if (count edges > 0 ) [\nforeach names-of-dimensions [\nset-current-plot-pen ?\nplot max [item get-dimension ? edge-degree-short-time] of edges \n]\n]"
PENS

MONITOR
505
640
600
685
Number of agents
count agents
17
1
11

SWITCH
150
245
285
278
Visualize-state?
Visualize-state?
0
1
-1000

PLOT
625
640
825
790
Overcrowded in %
NIL
NIL
0.0
10.0
0.0
100.0
true
true
"" ""
PENS
"Edges" 1.0 0 -7500403 true "" "if (count edges > 0) [\nplot (count edges with [edge-overcrowded?] / count edges * 100)\n]"
"Nodes" 1.0 0 -16777216 true "" "if (count nodes > 0) [\nplot (count nodes with [node-overcrowded?] / count nodes * 100)\n]"

MONITOR
320
745
600
790
Agent types (absolute, same order as in plot beside)
agent-type-count-vector
17
1
11

SLIDER
165
295
305
328
control-interval
control-interval
1
15
10
1
1
ticks
HORIZONTAL

PLOT
970
195
1275
365
Technologies used (in %) by agent-type
NIL
NIL
0.0
10.0
0.0
100.0
true
true
"foreach sort-on [technology-type-name] technology-types [\n  create-temporary-plot-pen [technology-type-name] of ?\n  set-plot-pen-color 8 * [who] of ?\n  ]" "if ((count technologies > 0) and (any? agents with [agent-type = plot-agent-type])) [\nforeach sort-on [technology-type-name] technology-types [\n  set-current-plot-pen [technology-type-name] of ?\n  plot (count agents with [agent-type = plot-agent-type AND [technology-name] of agent-technology-in-use = [technology-type-name] of ?]) / (count agents with [agent-type = plot-agent-type]) * 100\n  ]\n  ]"
PENS

CHOOSER
1135
370
1273
415
plot-agent-type
plot-agent-type
"pragmatic" "eco" "indifferent" "pennyPincher" "convenient"
3

CHOOSER
10
330
182
375
control-algorithm
control-algorithm
"soft-car" "strong-car" "soft-strong-car" "soft-car-emission" "soft-car-capacity" "soft-car-all" "strong-car-emission" "strong-car-capacity" "strong-car-all" "combined-car-emission" "combined-car-capacity" "combined-car-all"
0

BUTTON
195
575
305
608
Set value
set-technology-value technology-to-influence technology-dimension-to-influence read-from-string user-input \"Please specify the number to be used as new technology-value\"
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

PLOT
10
640
310
790
Population
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"foreach agent-types[\n  create-temporary-plot-pen ?\n  set-plot-pen-color 0.02 * string:hash-code ?\n  ]" "foreach agent-types [\n  set-current-plot-pen ?\n  plot (count agents with [agent-type = ?])\n  ]"
PENS

BUTTON
15
115
145
148
Save results
write-results
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
610
630
625
796
||\n||\n||\n||\n||\n||\n||\n||\n||\n||\n||\n||
11
0.0
1

TEXTBOX
975
430
1275
471
=====================================
11
0.0
1

@#$#@#$#@
The handbook is provided as separate document.

For general notes on SimCo, its usage and options to extending the model, please consult the in-code documentation and the additional paper decribing the purpose of SimCo.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

coal power plant
false
0
Rectangle -7500403 true true 36 95 59 231
Circle -1 true false 37 73 32
Circle -1 true false 55 38 54
Circle -1 true false 96 21 42
Circle -1 true false 105 40 32
Circle -1 true false 129 19 42
Rectangle -7500403 true true 14 228 78 270
Polygon -7500403 true true 105 105 105 210 90 270 180 270 165 210 165 105 105 105
Circle -1 true false 112 73 32
Circle -1 true false 130 38 54
Circle -1 true false 180 40 32
Circle -1 true false 171 21 42
Circle -1 true false 204 19 42
Polygon -7500403 true true 180 165 180 225 165 270 240 270 225 225 225 165 180 165
Circle -1 true false 187 133 32
Circle -1 true false 205 98 54
Circle -1 true false 246 81 42
Circle -1 true false 255 100 32
Circle -1 true false 264 64 42

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

electric substation
false
2
Polygon -1 true false 60 120 240 120 240 300 60 300 60 120
Polygon -1 true false 150 75 45 105 45 120 255 120 255 105 150 75
Polygon -7500403 false false 60 120 45 120 45 105 150 75 255 105 255 120 240 120 240 300 60 300 60 120 240 120
Polygon -955883 true true 165 180 120 240 150 240 135 285 180 225 150 225 165 180
Circle -955883 true true 75 135 30
Circle -955883 true true 195 135 30
Circle -955883 true true 135 135 30

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

factory
false
0
Rectangle -7500403 true true 76 194 285 270
Rectangle -7500403 true true 36 95 59 231
Rectangle -16777216 true false 90 210 270 240
Line -7500403 true 90 195 90 255
Line -7500403 true 120 195 120 255
Line -7500403 true 150 195 150 240
Line -7500403 true 180 195 180 255
Line -7500403 true 210 210 210 240
Line -7500403 true 240 210 240 240
Line -7500403 true 90 225 270 225
Circle -1 true false 37 73 32
Circle -1 true false 55 38 54
Circle -1 true false 96 21 42
Circle -1 true false 105 40 32
Circle -1 true false 129 19 42
Rectangle -7500403 true true 14 228 78 270

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

house efficiency
false
0
Rectangle -7500403 true true 180 90 195 195
Rectangle -7500403 true true 90 165 210 255
Rectangle -16777216 true false 165 195 195 255
Rectangle -16777216 true false 105 202 135 240
Polygon -7500403 true true 225 165 75 165 150 90
Line -16777216 false 90 165 210 165

house enet
false
1
Rectangle -2674135 true true 90 165 210 255
Rectangle -16777216 true false 165 225 180 255
Polygon -2674135 true true 225 165 75 165 150 90
Polygon -7500403 true false 180 90 195 90 195 135 180 120 180 90
Rectangle -16777216 true false 120 180 135 195
Rectangle -16777216 true false 165 180 180 195
Polygon -7500403 false false 90 165 90 255 210 255 210 165 225 165 150 90 75 165 90 165 210 165

invisible
true
0

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

pv plant
false
14
Rectangle -7500403 true false 180 90 225 135
Rectangle -7500403 true false 105 165 150 210
Polygon -16777216 true true 30 180 105 225 255 75 180 30 30 180
Line -7500403 false 180 30 30 180
Line -7500403 false 180 30 255 75
Line -7500403 false 30 180 105 225
Line -7500403 false 255 75 105 225
Line -7500403 false 225 75 90 210
Line -7500403 false 210 60 75 195
Line -7500403 false 195 45 60 180
Line -7500403 false 150 60 225 105
Line -7500403 false 120 90 195 135
Line -7500403 false 90 120 165 165
Line -7500403 false 60 150 135 195

pv plant old
false
14
Polygon -16777216 true true 165 105 30 195 150 180 285 90 165 105
Rectangle -16777216 true true 195 105 225 150
Rectangle -16777216 true true 105 150 135 195
Line -7500403 false 75 180 195 105
Line -7500403 false 90 180 210 105
Line -7500403 false 105 180 225 105
Line -7500403 false 120 180 240 105
Line -7500403 false 60 180 180 105
Line -7500403 false 135 180 255 105
Line -7500403 false 135 120 255 105
Line -7500403 false 120 135 240 120
Line -7500403 false 90 150 210 135
Line -7500403 false 75 165 195 150
Line -7500403 false 45 180 165 165

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wind turbine
false
14
Polygon -16777216 true true 135 120 150 135 60 225 135 120
Polygon -16777216 true true 150 105 135 120 45 30 150 105
Polygon -16777216 true true 165 120 150 105 240 15 165 120
Polygon -16777216 true true 150 135 165 120 255 210 150 135
Polygon -16777216 true true 150 105 135 300 165 300 150 105
Circle -7500403 true false 135 105 30
Line -1 false 135 120 150 135
Line -1 false 135 120 150 105
Line -1 false 150 105 165 120
Line -1 false 165 120 150 135

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="base-experiment" repetitions="1" runMetricsEveryStep="true">
    <setup>setup
print "setup done"
set-technology-value technology-to-influence technology-dimension-to-influence technology-value-helper
print "setup technology-value (static control) done"</setup>
    <go>go</go>
    <final>write-results
	clear-all</final>
    <timeLimit steps="8000"/>
    <metric>count-agent-type</metric>
    <metric>deaths</metric>
    <metric>technology-usage-vector-percentage</metric>
    <metric>technology-usage-vector-per-agentType-percentage</metric>
    <metric>mean [item 0 edge-pay-offs-short-time] of edges</metric>
    <metric>max [item 0 edge-pay-offs-short-time] of edges</metric>
    <metric>mean [item 3 edge-pay-offs-short-time] of edges</metric>
    <metric>max [item 3 edge-pay-offs-short-time] of edges</metric>
    <metric>mean [item 0 node-pay-offs-short-time] of nodes</metric>
    <metric>max [item 0 node-pay-offs-short-time] of nodes</metric>
    <metric>mean [item 3 node-pay-offs-short-time] of nodes</metric>
    <metric>max [item 3 node-pay-offs-short-time] of nodes</metric>
    <metric>mean [item 0 edge-pay-offs-long-time] of edges</metric>
    <metric>max [item 0 edge-pay-offs-long-time] of edges</metric>
    <metric>mean [item 3 edge-pay-offs-long-time] of edges</metric>
    <metric>max [item 3 edge-pay-offs-long-time] of edges</metric>
    <metric>mean [item 0 node-pay-offs-long-time] of nodes</metric>
    <metric>max [item 0 node-pay-offs-long-time] of nodes</metric>
    <metric>mean [item 3 node-pay-offs-long-time] of nodes</metric>
    <metric>max [item 3 node-pay-offs-long-time] of nodes</metric>
    <metric>mean [item 0 edge-degree-short-time] of edges</metric>
    <metric>max [item 0 edge-degree-short-time] of edges</metric>
    <metric>mean [item 3 edge-degree-short-time] of edges</metric>
    <metric>max [item 3 edge-degree-short-time] of edges</metric>
    <metric>mean [item 0 node-degree-short-time] of nodes</metric>
    <metric>max [item 0 node-degree-short-time] of nodes</metric>
    <metric>mean [item 3 node-degree-short-time] of nodes</metric>
    <metric>max [item 3 node-degree-short-time] of nodes</metric>
    <metric>mean [item 0 edge-degree-long-time] of edges</metric>
    <metric>max [item 0 edge-degree-long-time] of edges</metric>
    <metric>mean [item 3 edge-degree-long-time] of edges</metric>
    <metric>max [item 3 edge-degree-long-time] of edges</metric>
    <metric>mean [item 0 node-degree-long-time] of nodes</metric>
    <metric>max [item 0 node-degree-long-time] of nodes</metric>
    <metric>mean [item 3 node-degree-long-time] of nodes</metric>
    <metric>max [item 3 node-degree-long-time] of nodes</metric>
    <metric>mean [item 1 agent-pay-offs / agent-age] of agents with [agent-type = "convenient"]</metric>
    <metric>mean [item 1 agent-pay-offs / agent-age] of agents with [agent-type = "eco"]</metric>
    <metric>mean [item 1 agent-pay-offs / agent-age] of agents with [agent-type = "indifferent"]</metric>
    <metric>mean [item 1 agent-pay-offs / agent-age] of agents with [agent-type = "pragmatist"]</metric>
    <metric>mean [item 1 agent-pay-offs / agent-age] of agents with [agent-type = "saver"]</metric>
    <metric>agent-types-alive</metric>
    <metric>count agents with [agent-stuck?]</metric>
    <metric>mean [item 1 table:get  [edge-costs-benefits-agents-control-factor-per-technology] of self "car"] of edges</metric>
    <metric>mean [item 1 table:get  [node-costs-benefits-agents-control-factor-per-technology] of self "car"] of nodes</metric>
    <metric>max [item 1 table:get  [edge-costs-benefits-agents-control-factor-per-technology] of self "car"] of edges</metric>
    <metric>max [item 1 table:get  [node-costs-benefits-agents-control-factor-per-technology] of self "car"] of nodes</metric>
    <metric>count edges with [item 1 table:get [edge-costs-benefits-agents-control-factor-per-technology] of self "car"&gt; 1 ]</metric>
    <metric>count nodes with [item 1 table:get [node-costs-benefits-agents-control-factor-per-technology] of self "car"&gt; 1 ]</metric>
    <metric>seu-mean-per-agent-type</metric>
    <metric>mean [agent-seu-value] of agents</metric>
    <metric>count edges with [edge-overcrowded?]</metric>
    <metric>count nodes with [node-overcrowded?]</metric>
    <enumeratedValueSet variable="automated-run?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-history?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wa-h?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wa-seu?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wa-sr?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wa-s?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wn-s?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wn-sr?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wn-h?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="we-sr?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="we-s?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="we-h?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wt-sr?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wt-s?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-sr?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-s?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-plot-populated?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-plot-overcrowded?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-plot-mean-degree-edges?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-plot-max-degree-edges?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-plot-edges-with-techs-banned?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-plot-technologies-used?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ww?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="out?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="automated-control?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-algorithm">
      <value value="&quot;none&quot;"/>
      <value value="&quot;soft-car&quot;"/>
      <value value="&quot;hard-car&quot;"/>
      <value value="&quot;soft-hard-car&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-interval">
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="automated-control-soft-min-value">
      <value value="1"/>
      <value value="1.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="automated-control-soft-max-value">
      <value value="2.5"/>
      <value value="3"/>
      <value value="3.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="automated-control-soft-increase-factor">
      <value value="1.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="automated-control-soft-decrease-factor">
      <value value="1.1"/>
    </enumeratedValueSet>
    <steppedValueSet variable="technology-value-helper" first="1" step="0.1" last="2"/>
    <enumeratedValueSet variable="technology-to-influence">
      <value value="&quot;bike&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="technology-dimension-to-influence">
      <value value="&quot;Comfort&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="purchase?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="technology-lifetime-random?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed">
      <value value="1500"/>
      <value value="98567"/>
      <value value="699521148"/>
      <value value="98432468"/>
      <value value="786145876"/>
      <value value="900719254"/>
      <value value="-878265114"/>
      <value value="14569875"/>
      <value value="64384"/>
      <value value="654668668"/>
      <value value="16684365"/>
      <value value="-614573582"/>
      <value value="867684"/>
      <value value="-4582"/>
      <value value="73582"/>
      <value value="982"/>
      <value value="-61482"/>
      <value value="-573582"/>
      <value value="-6142"/>
      <value value="7235395"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="standard-file">
      <value value="&quot;DiscGoAS2201Modif.snf&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seu-fuzzy-factor">
      <value value="0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="base-experiment-bike-comfort-static" repetitions="1" runMetricsEveryStep="true">
    <setup>setup
print "setup done"
set-technology-value technology-to-influence technology-dimension-to-influence technology-value-helper
print "setup technology-value (static control) done"</setup>
    <go>go</go>
    <final>write-results
	clear-all</final>
    <timeLimit steps="8000"/>
    <metric>count-agent-type</metric>
    <metric>deaths</metric>
    <metric>technology-usage-vector-percentage</metric>
    <metric>technology-usage-vector-per-agentType-percentage</metric>
    <metric>mean [item 0 edge-pay-offs-short-time] of edges</metric>
    <metric>max [item 0 edge-pay-offs-short-time] of edges</metric>
    <metric>mean [item 3 edge-pay-offs-short-time] of edges</metric>
    <metric>max [item 3 edge-pay-offs-short-time] of edges</metric>
    <metric>mean [item 0 node-pay-offs-short-time] of nodes</metric>
    <metric>max [item 0 node-pay-offs-short-time] of nodes</metric>
    <metric>mean [item 3 node-pay-offs-short-time] of nodes</metric>
    <metric>max [item 3 node-pay-offs-short-time] of nodes</metric>
    <metric>mean [item 0 edge-pay-offs-long-time] of edges</metric>
    <metric>max [item 0 edge-pay-offs-long-time] of edges</metric>
    <metric>mean [item 3 edge-pay-offs-long-time] of edges</metric>
    <metric>max [item 3 edge-pay-offs-long-time] of edges</metric>
    <metric>mean [item 0 node-pay-offs-long-time] of nodes</metric>
    <metric>max [item 0 node-pay-offs-long-time] of nodes</metric>
    <metric>mean [item 3 node-pay-offs-long-time] of nodes</metric>
    <metric>max [item 3 node-pay-offs-long-time] of nodes</metric>
    <metric>mean [item 0 edge-degree-short-time] of edges</metric>
    <metric>max [item 0 edge-degree-short-time] of edges</metric>
    <metric>mean [item 3 edge-degree-short-time] of edges</metric>
    <metric>max [item 3 edge-degree-short-time] of edges</metric>
    <metric>mean [item 0 node-degree-short-time] of nodes</metric>
    <metric>max [item 0 node-degree-short-time] of nodes</metric>
    <metric>mean [item 3 node-degree-short-time] of nodes</metric>
    <metric>max [item 3 node-degree-short-time] of nodes</metric>
    <metric>mean [item 0 edge-degree-long-time] of edges</metric>
    <metric>max [item 0 edge-degree-long-time] of edges</metric>
    <metric>mean [item 3 edge-degree-long-time] of edges</metric>
    <metric>max [item 3 edge-degree-long-time] of edges</metric>
    <metric>mean [item 0 node-degree-long-time] of nodes</metric>
    <metric>max [item 0 node-degree-long-time] of nodes</metric>
    <metric>mean [item 3 node-degree-long-time] of nodes</metric>
    <metric>max [item 3 node-degree-long-time] of nodes</metric>
    <metric>mean [item 1 agent-pay-offs / agent-age] of agents with [agent-type = "convenient"]</metric>
    <metric>mean [item 1 agent-pay-offs / agent-age] of agents with [agent-type = "eco"]</metric>
    <metric>mean [item 1 agent-pay-offs / agent-age] of agents with [agent-type = "indifferent"]</metric>
    <metric>mean [item 1 agent-pay-offs / agent-age] of agents with [agent-type = "pragmatist"]</metric>
    <metric>mean [item 1 agent-pay-offs / agent-age] of agents with [agent-type = "saver"]</metric>
    <metric>agent-types-alive</metric>
    <metric>count agents with [agent-stuck?]</metric>
    <metric>mean [item 1 table:get  [edge-costs-benefits-agents-control-factor-per-technology] of self "car"] of edges</metric>
    <metric>mean [item 1 table:get  [node-costs-benefits-agents-control-factor-per-technology] of self "car"] of nodes</metric>
    <metric>max [item 1 table:get  [edge-costs-benefits-agents-control-factor-per-technology] of self "car"] of edges</metric>
    <metric>max [item 1 table:get  [node-costs-benefits-agents-control-factor-per-technology] of self "car"] of nodes</metric>
    <metric>count edges with [item 1 table:get [edge-costs-benefits-agents-control-factor-per-technology] of self "car"&gt; 1 ]</metric>
    <metric>count nodes with [item 1 table:get [node-costs-benefits-agents-control-factor-per-technology] of self "car"&gt; 1 ]</metric>
    <metric>seu-mean-per-agent-type</metric>
    <metric>mean [agent-seu-value] of agents</metric>
    <metric>count edges with [edge-overcrowded?]</metric>
    <metric>count nodes with [node-overcrowded?]</metric>
    <enumeratedValueSet variable="automated-run?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-history?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wa-h?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wa-seu?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wa-sr?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wa-s?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wn-s?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wn-sr?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wn-h?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="we-sr?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="we-s?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="we-h?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wt-sr?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wt-s?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-sr?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-s?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-plot-populated?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-plot-overcrowded?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-plot-mean-degree-edges?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-plot-max-degree-edges?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-plot-edges-with-techs-banned?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-plot-technologies-used?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ww?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="out?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="automated-control?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-algorithm">
      <value value="&quot;none&quot;"/>
      <value value="&quot;soft-car&quot;"/>
      <value value="&quot;hard-car&quot;"/>
      <value value="&quot;soft-hard-car&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-interval">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="automated-control-soft-min-value">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="automated-control-soft-max-value">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="automated-control-soft-increase-factor">
      <value value="1.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="automated-control-soft-decrease-factor">
      <value value="1.1"/>
    </enumeratedValueSet>
    <steppedValueSet variable="technology-value-helper" first="1" step="0.1" last="2"/>
    <enumeratedValueSet variable="technology-to-influence">
      <value value="&quot;bike&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="technology-dimension-to-influence">
      <value value="&quot;Comfort&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="purchase?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="technology-lifetime-random?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed">
      <value value="1500"/>
      <value value="98567"/>
      <value value="699521148"/>
      <value value="98432468"/>
      <value value="786145876"/>
      <value value="900719254"/>
      <value value="-878265114"/>
      <value value="14569875"/>
      <value value="64384"/>
      <value value="654668668"/>
      <value value="16684365"/>
      <value value="-614573582"/>
      <value value="867684"/>
      <value value="-4582"/>
      <value value="73582"/>
      <value value="982"/>
      <value value="-61482"/>
      <value value="-573582"/>
      <value value="-6142"/>
      <value value="7235395"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="standard-file">
      <value value="&quot;DiscGoAS2201Modif.snf&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seu-fuzzy-factor">
      <value value="0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="base-experiment-bike-comfort-static-duration-car" repetitions="1" runMetricsEveryStep="true">
    <setup>setup
print "setup done"
set-technology-value technology-to-influence technology-dimension-to-influence technology-value-helper
print "setup technology-value (static control) done"
set-technology-speed-factor "car" "shared-small" 1.5</setup>
    <go>go</go>
    <final>write-results
	clear-all</final>
    <timeLimit steps="8000"/>
    <metric>count-agent-type</metric>
    <metric>deaths</metric>
    <metric>technology-usage-vector-percentage</metric>
    <metric>technology-usage-vector-per-agentType-percentage</metric>
    <metric>mean [item 0 edge-pay-offs-short-time] of edges</metric>
    <metric>max [item 0 edge-pay-offs-short-time] of edges</metric>
    <metric>mean [item 3 edge-pay-offs-short-time] of edges</metric>
    <metric>max [item 3 edge-pay-offs-short-time] of edges</metric>
    <metric>mean [item 0 node-pay-offs-short-time] of nodes</metric>
    <metric>max [item 0 node-pay-offs-short-time] of nodes</metric>
    <metric>mean [item 3 node-pay-offs-short-time] of nodes</metric>
    <metric>max [item 3 node-pay-offs-short-time] of nodes</metric>
    <metric>mean [item 0 edge-pay-offs-long-time] of edges</metric>
    <metric>max [item 0 edge-pay-offs-long-time] of edges</metric>
    <metric>mean [item 3 edge-pay-offs-long-time] of edges</metric>
    <metric>max [item 3 edge-pay-offs-long-time] of edges</metric>
    <metric>mean [item 0 node-pay-offs-long-time] of nodes</metric>
    <metric>max [item 0 node-pay-offs-long-time] of nodes</metric>
    <metric>mean [item 3 node-pay-offs-long-time] of nodes</metric>
    <metric>max [item 3 node-pay-offs-long-time] of nodes</metric>
    <metric>mean [item 0 edge-degree-short-time] of edges</metric>
    <metric>max [item 0 edge-degree-short-time] of edges</metric>
    <metric>mean [item 3 edge-degree-short-time] of edges</metric>
    <metric>max [item 3 edge-degree-short-time] of edges</metric>
    <metric>mean [item 0 node-degree-short-time] of nodes</metric>
    <metric>max [item 0 node-degree-short-time] of nodes</metric>
    <metric>mean [item 3 node-degree-short-time] of nodes</metric>
    <metric>max [item 3 node-degree-short-time] of nodes</metric>
    <metric>mean [item 0 edge-degree-long-time] of edges</metric>
    <metric>max [item 0 edge-degree-long-time] of edges</metric>
    <metric>mean [item 3 edge-degree-long-time] of edges</metric>
    <metric>max [item 3 edge-degree-long-time] of edges</metric>
    <metric>mean [item 0 node-degree-long-time] of nodes</metric>
    <metric>max [item 0 node-degree-long-time] of nodes</metric>
    <metric>mean [item 3 node-degree-long-time] of nodes</metric>
    <metric>max [item 3 node-degree-long-time] of nodes</metric>
    <metric>mean [item 1 agent-pay-offs / agent-age] of agents with [agent-type = "convenient"]</metric>
    <metric>mean [item 1 agent-pay-offs / agent-age] of agents with [agent-type = "eco"]</metric>
    <metric>mean [item 1 agent-pay-offs / agent-age] of agents with [agent-type = "indifferent"]</metric>
    <metric>mean [item 1 agent-pay-offs / agent-age] of agents with [agent-type = "pragmatist"]</metric>
    <metric>mean [item 1 agent-pay-offs / agent-age] of agents with [agent-type = "saver"]</metric>
    <metric>agent-types-alive</metric>
    <metric>count agents with [agent-stuck?]</metric>
    <metric>mean [item 1 table:get  [edge-costs-benefits-agents-control-factor-per-technology] of self "car"] of edges</metric>
    <metric>mean [item 1 table:get  [node-costs-benefits-agents-control-factor-per-technology] of self "car"] of nodes</metric>
    <metric>max [item 1 table:get  [edge-costs-benefits-agents-control-factor-per-technology] of self "car"] of edges</metric>
    <metric>max [item 1 table:get  [node-costs-benefits-agents-control-factor-per-technology] of self "car"] of nodes</metric>
    <metric>count edges with [item 1 table:get [edge-costs-benefits-agents-control-factor-per-technology] of self "car"&gt; 1 ]</metric>
    <metric>count nodes with [item 1 table:get [node-costs-benefits-agents-control-factor-per-technology] of self "car"&gt; 1 ]</metric>
    <metric>seu-mean-per-agent-type</metric>
    <metric>mean [agent-seu-value] of agents</metric>
    <metric>count edges with [edge-overcrowded?]</metric>
    <metric>count nodes with [node-overcrowded?]</metric>
    <enumeratedValueSet variable="automated-run?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-history?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wa-h?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wa-seu?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wa-sr?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wa-s?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wn-s?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wn-sr?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wn-h?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="we-sr?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="we-s?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="we-h?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wt-sr?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wt-s?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-sr?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-s?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-plot-populated?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-plot-overcrowded?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-plot-mean-degree-edges?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-plot-max-degree-edges?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-plot-edges-with-techs-banned?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wg-plot-technologies-used?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ww?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="out?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="automated-control?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-algorithm">
      <value value="&quot;none&quot;"/>
      <value value="&quot;soft-car&quot;"/>
      <value value="&quot;hard-car&quot;"/>
      <value value="&quot;soft-hard-car&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-interval">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="automated-control-soft-min-value">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="automated-control-soft-max-value">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="automated-control-soft-increase-factor">
      <value value="1.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="automated-control-soft-decrease-factor">
      <value value="1.1"/>
    </enumeratedValueSet>
    <steppedValueSet variable="technology-value-helper" first="1" step="0.1" last="2"/>
    <enumeratedValueSet variable="technology-to-influence">
      <value value="&quot;bike&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="technology-dimension-to-influence">
      <value value="&quot;Comfort&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="purchase?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="technology-lifetime-random?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed">
      <value value="1500"/>
      <value value="98567"/>
      <value value="699521148"/>
      <value value="98432468"/>
      <value value="786145876"/>
      <value value="900719254"/>
      <value value="-878265114"/>
      <value value="14569875"/>
      <value value="64384"/>
      <value value="654668668"/>
      <value value="16684365"/>
      <value value="-614573582"/>
      <value value="867684"/>
      <value value="-4582"/>
      <value value="73582"/>
      <value value="982"/>
      <value value="-61482"/>
      <value value="-573582"/>
      <value value="-6142"/>
      <value value="7235395"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="standard-file">
      <value value="&quot;DiscGoAS2201Modif.snf&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seu-fuzzy-factor">
      <value value="0.9"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
VIEW
206
10
635
439
0
0
0
1
1
1
1
1
0
1
1
1
-17
17
-16
16

CHOOSER
15
20
153
65
time
time
"short" "long"
1

CHOOSER
15
75
153
120
dimension
dimension
0 1 2
0

@#$#@#$#@
default
0.0
-0.2 1 1.0 0.0
0.0 1 1.0 0.0
0.2 1 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

mactest
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 120 180
Line -7500403 true 150 150 180 180

small arrowhead curved
1.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 120 180
Line -7500403 true 150 150 180 180

small arrowhead straight
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 135 165
Line -7500403 true 150 150 165 165

@#$#@#$#@
1
@#$#@#$#@
